@@ -58,19 +58,6 @@ const ModeController = new Lang.Class({
         this._mode = mode;
 
         this.emit('window-mode-changed', this._mode, oldMode);
-
-        if (mode != WindowMode.PREVIEW)
-            return;
-
-        let window = Application.application.get_active_window();
-        let gdkWindow = window.get_window();
-
-        if (gdkWindow) {
-            let windowState = gdkWindow.get_state();
-
-            if (windowState & Gdk.WindowState.MAXIMIZED)
-                this.setFullscreen(true);
-        }
     },
 
     getWindowMode: function() {
